summaryrefslogtreecommitdiff
path: root/plugins/elf/dynamic.h
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/elf/dynamic.h')
-rw-r--r--plugins/elf/dynamic.h14
1 files changed, 10 insertions, 4 deletions
diff --git a/plugins/elf/dynamic.h b/plugins/elf/dynamic.h
index 1ca4785..62e8b39 100644
--- a/plugins/elf/dynamic.h
+++ b/plugins/elf/dynamic.h
@@ -33,11 +33,17 @@
/* Recherche un en-tête de programme DYNAMIC au sein de binaire. */
bool find_elf_dynamic_program_header(const GElfFormat *, elf_phdr *);
-/* Retrouve un élément donné dans la section dynamique. */
-bool find_elf_dynamic_item_from_pheader(const GElfFormat *, const elf_phdr *, int64_t, elf_dyn *);
+/* Retrouve un élément dans la section dynamique par son indice. */
+bool _find_elf_dynamic_item_by_index(const GElfFormat *, const elf_phdr *, size_t, elf_dyn *);
-/* Retrouve rapidement un élément dans la section dynamique. */
-bool find_elf_dynamic_item(const GElfFormat *, int64_t, elf_dyn *);
+/* Retrouve un élément dans la section dynamique par son indice. */
+bool find_elf_dynamic_item_by_index(const GElfFormat *, size_t, elf_dyn *);
+
+/* Retrouve un élément dans la section dynamique par son type. */
+bool _find_elf_dynamic_item_by_type(const GElfFormat *, const elf_phdr *, int64_t, elf_dyn *);
+
+/* Retrouve un élément dans la section dynamique par son type. */
+bool find_elf_dynamic_item_by_type(const GElfFormat *, int64_t, elf_dyn *);
/* Fournit la liste des objets partagés requis. */
const char **list_elf_needed_objects(const GElfFormat *, size_t *);